@@ -522,7 +522,7 @@ int cram_index_build(cram_fd *fd, const char *fn_base) {
 
         if (fd->err) {
             perror("Cram container read");
-            return 1;
+            return -1;
         }
 
 	if (seekable) {
@@ -533,7 +533,7 @@ int cram_index_build(cram_fd *fd, const char *fn_base) {
 	}
 
         if (!(c->comp_hdr_block = cram_read_block(fd)))
-            return 1;
+            return -1;
         assert(c->comp_hdr_block->content_type == COMPRESSION_HEADER);
 
         c->comp_hdr = cram_decode_compression_header(fd, c->comp_hdr_block);
@@ -595,5 +595,5 @@ int cram_index_build(cram_fd *fd, const char *fn_base) {
     }
 	
 
-    return zfclose(fp);
+    return (zfclose(fp) >= 0) ? 0 : -1;
 }
